/**
 * Copyright (c) 2013-2016 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.microkernel.api.jbi.messaging.endpoint.exception;

import javax.xml.namespace.QName;

import org.ow2.petals.clientserverapi.jbi.messaging.endpoint.exception.EndpointDirectoryException;

/**
 * The endpoint does not exist in the registry
 * 
 * @author Christophe DENEUX - Linagora
 */
public class EndpointDoesNotExistsException extends EndpointDirectoryException {

    private static final long serialVersionUID = 6827091489571462897L;

    private static final String MESSAGE_PATTERN = "The endpoint '%s' for service '%s' does not exist in the endpoint directory.";

    /**
     * Name of the not existing endpoint.
     */
    private final String notExistingEndpointName;

    /**
     * Service name of the not existing existing endpoint.
     */
    private final QName notExistingEndpointService;

    public EndpointDoesNotExistsException(final String notExistingEndpointName, final QName notExistingEndpointService) {
        super(String.format(MESSAGE_PATTERN, notExistingEndpointName, notExistingEndpointService.toString()));
        this.notExistingEndpointName = notExistingEndpointName;
        this.notExistingEndpointService = notExistingEndpointService;
    }

    public String getNotExistingEndpointName() {
        return this.notExistingEndpointName;
    }

    public QName getNotExistingEndpointService() {
        return this.notExistingEndpointService;
    }

}
